Pool

Struct Pool 

pub struct Pool<const N: usize, const NSYMS: usize> {
    pub progresses: Vec<CycleProgress<N, NSYMS>>,
    pub handles: Vec<JoinHandle<Candidate<N, NSYMS>>>,
    pub sigint: Arc<AtomicBool>,
}
Run the algorithm on a set of populations simultaneously using multithreading.

Set sigint to true to stop the iterations manually.

Fields

progresses: Vec<CycleProgress<N, NSYMS>>handles: Vec<JoinHandle<Candidate<N, NSYMS>>>sigint: Arc<AtomicBool>

Implementations

Source

impl<const N: usize, const NSYMS: usize> Pool<N, NSYMS>

pub fn new( gas: Arc<Gas<N, NSYMS>>, nthreads: usize, sigint: Arc<AtomicBool>, ) -> Pool<N, NSYMS>

pub fn is_finished(&self) -> bool

pub fn winner(&mut self, gas: Arc<Gas<N, NSYMS>>) -> Candidate<N, NSYMS>