pub struct Pool<const N: usize, const NSYMS: usize> {
pub progresses: Vec<CycleProgress<N, NSYMS>>,
pub handles: Vec<JoinHandle<Candidate<N, NSYMS>>>,
pub sigint: Arc<AtomicBool>,
}Expand description
Run the algorithm on a set of populations simultaneously using multithreading.
Set sigint to true to stop the iterations manually.
Fields
progresses: Vec<CycleProgress<N, NSYMS>>handles: Vec<JoinHandle<Candidate<N, NSYMS>>>sigint: Arc<AtomicBool>Implementations